'use strict';

const isSourcePackage = (node) => {
  const source = node.source.raw;
  if (!source) {
    return false;
  }
  return source.startsWith("'@guardian/src-") || source.startsWith("'@guardian/source-");
};
const noStarImportsOrExports = {
  meta: {
    type: "problem",
    docs: {
      description: "Disallow * imports and exports",
      category: "Possible Problems",
      url: "https://github.com/guardian/csnx/tree/main/libs/@guardian/eslint-plugin-source-foundations/README.md"
    }
  },
  create(context) {
    return {
      ImportDeclaration(node) {
        if (!isSourcePackage(node)) {
          return;
        }
        const anyNamespaceSpecifiers = !node.specifiers.every(
          (s) => s.type !== "ImportNamespaceSpecifier"
        );
        if (!anyNamespaceSpecifiers) {
          return;
        }
        return context.report({
          node,
          message: "Importing * from @guardian/src-* and @guardian/source-* packages is not recommended. Use named imports instead."
        });
      },
      ExportAllDeclaration(node) {
        if (!isSourcePackage(node)) {
          return;
        }
        return context.report({
          node,
          message: "Exporting * from @guardian/src-* and @guardian/source-* packages is not recommended. Use named exports instead."
        });
      }
    };
  }
};

exports.noStarImportsOrExports = noStarImportsOrExports;
